@@ -30,7 +30,7 @@ help_schema = {
 
 parameter_field_schema = {
     "help": help_schema.copy(),
-    "collapsed": {"required": False, "type": "boolean",},
+    "collapsed": {"required": False, "type": "boolean"},
     "required": {"required": False, "type": "boolean"},
     "choices": {"dependencies": {"type": ["enum"]}, "type": "list"},
     "connection_type_uuid": {"dependencies": {"type": ["connection"]}, "type": "string"},
@@ -74,7 +74,7 @@ parameter_group_schema = {
     },
     "description": {"type": "string", "required": False},
     "name": {"type": "string", "required": True},
-    "type": {"allowed": ["group"], "required": True,},
+    "type": {"allowed": ["group"], "required": True},
     "parameters": {
         "type": "list",
         "schema": {"type": "dict", "schema": parameter_field_schema.copy()},
